@@ -99,9 +99,12 @@ class FSLeyesApp(wx.App):
 
         self.SetAppName('FSLeyes')
 
-        self.__icon = wx.adv.TaskBarIcon(iconType=wx.adv.TBI_DOCK)
-        self.__icon.SetIcon(wx.Icon(
-            op.join(fsleyes.assetDir, 'assets', 'icons', 'app_icon.png')))
+        try:
+            self.__icon = wx.adv.TaskBarIcon(iconType=wx.adv.TBI_DOCK)
+            self.__icon.SetIcon(wx.Icon(
+                op.join(fsleyes.assetDir, 'assets', 'icons', 'app_icon.png')))
+        except Exception:
+            self.__icon = None
 
 
     @property
@@ -418,9 +421,12 @@ def embed(parent, callback=None, **kwargs):
     :arg parent:   ``wx`` parent object
     :arg callback: A function which will be called when FSLeyes
                    is ready. Must accept three positional arguments:
-                     - The :class:`.OverlayList`
-                     - The master :class:`.DisplayContext`
-                     - The :class:`.FSLeyesFrame`
+
+                    - The :class:`.OverlayList`
+
+                    - The master :class:`.DisplayContext`
+
+                    - The :class:`.FSLeyesFrame`
 
     All other arguments are passed to :meth:`.FSLeyesFrame.__init__`.
     """
